#!/bin/bash
# This script will remove all by the latest file in your /p4/1/depots/ tree.
# It is designed to work with servers running with lbr.autocompress=1 set in the configurables.
export SDP_INSTANCE=${SDP_INSTANCE:-Undefined}
export SDP_INSTANCE=${1:-$SDP_INSTANCE}
if [[ $SDP_INSTANCE == Undefined ]]; then
   echo "Instance parameter not supplied."
   echo "You must supply the Perforce instance as a parameter to this script."
   exit 1
fi

if [[ -f /p4/${SDP_INSTANCE}/bin/skip_cache_clean.txt ]]; then
  exit 0

# Check to make sure that global shelves are enabled. If they are not, this script
# would most likely end up deleting someone's shelved files.
if [[ ! $(p4 -ztag -F %Value% configure show dm.shelve.promote) ]]; then
  echo "Global shelves are not enabled, aborting!"
  exit 1
fi

IFS=$'\n' array=($(find '/p4/${SDP_INSTANCE}/depots/' -type d | grep ",d" | uniq ))
for dir in "${array[@]}"
do
  echo $dir >> $P4LOGS/cachecclean.log
  if [[ !($dir =~ .*unload.*) || !($dir =~ .*spec.*) ]]; then
    farray=($(ls -t $dir | awk "NR > 3"))
    for dfile in "${farray[@]}"
    do
      rm -f "$dir/$dfile"
    done
  fi
done
